aboutsummaryrefslogtreecommitdiffstats
path: root/examples
diff options
context:
space:
mode:
authorLev Walkin <vlm@lionet.info>2013-10-24 01:36:43 -0700
committerLev Walkin <vlm@lionet.info>2013-10-24 01:36:43 -0700
commit98e9b9399734120be9ea36f8e90d3c2ad1ef2a75 (patch)
treea35e63f65eefc3d1a267620e94fd76920a86f413 /examples
parentf65e93775938ff7df916ab40736d8faf943bcf46 (diff)
comments changed
Diffstat (limited to 'examples')
-rwxr-xr-xexamples/crfc2asn1.pl8
1 files changed, 2 insertions, 6 deletions
diff --git a/examples/crfc2asn1.pl b/examples/crfc2asn1.pl
index 74591948..c942f098 100755
--- a/examples/crfc2asn1.pl
+++ b/examples/crfc2asn1.pl
@@ -1,10 +1,6 @@
#!/usr/bin/env perl
-
-#
-# $Id$
-# $Author$
#
# Simple tool to fetch the ASN.1 specifications from the given set of RFC files.
#
@@ -13,7 +9,7 @@ my $found = 0;
my $currentFname = '';
if(-t STDIN && $#ARGV == -1) {
- print STDERR "Rip ASN.1 specification from RFC file\n";
+ print STDERR "Extract ASN.1 specification from the RFC file\n";
print STDERR "Usage: $0 <rfc-file.txt> ...\n";
print STDERR "Usage: <someprog> | $0\n";
exit(1);
@@ -1,10 +1,6 @@
#
-# Simple tool to fetch the ASN.1 specifications from the given set of RFC files.
+# Extract the ASN.1 module text from the given set of RFC files.
#